%define pam_ldap_version 124
Summary: NSS library and PAM module for LDAP.
Name: nss_ldap
Version: 172
Release: 3.2
Source0: ftp://ftp.padl.com/pub/%{name}-%{version}.tar.gz
Source1: ftp://ftp.padl.com/pub/pam_ldap-%{pam_ldap_version}.tar.gz
Patch0: nss_ldap-172-autoconf.patch
Patch1: pam_ldap-46-pam_console.patch
Patch2: pam_ldap-122-dnsconfig.patch
URL: http://www.padl.com/
License: LGPL
Group: System Environment/Base
BuildRoot: %{_tmppath}/%{name}-root
BuildPrereq: autoconf, automake, cyrus-sasl-devel >= 1.5.24-14, db3-devel
BuildPrereq: gdbm-devel, krb5-devel, libtool, openldap-devel >= 2.0
BuildPrereq: openssl-devel, pam-devel
Requires: nscd
Obsoletes: pam_ldap

%description
This package includes two LDAP access clients: nss_ldap and pam_ldap.
Nss_ldap is a set of C library extensions that allow X.500 and LDAP
directory servers to be used as a primary source of aliases, ethers,
groups, hosts, networks, protocol, users, RPCs, services, and shadow
passwords (instead of or in addition to using flat files or NIS).

Pam_ldap is a module for Linux-PAM that supports password changes, V2
clients, Netscape's SSL, ypldapd, Netscape Directory Server password
policies, access authorization, and crypted hashes.

%prep
%setup -q -a 1
%patch0 -p1 -b .autoconf
cp -f /usr/share/libtool/config.{guess,sub} .

pushd pam_ldap-%{pam_ldap_version}
%patch1 -p2 -b .pam_console
%patch2 -p1 -b .dnsconfig
cp -f /usr/share/libtool/config.{guess,sub} .
cp ../resolve.c .
cp ../resolve.h .
cp ../snprintf.c .
cp ../snprintf.h .
aclocal
automake -a
autoheader
autoconf
popd

rm -f pam.d/*.pam_console
rm -f pam.d/*.redhat
aclocal
automake -a
autoheader
autoconf

%build
# Set the CFLAGS to make sure -fPIC is *always* used.  Set LIBS to the set of
# libraries we have to link statically with because they're in /usr, but don't
# export it to the configure script.
CFLAGS="$RPM_OPT_FLAGS -fPIC"; export CFLAGS
STATICLIBS="-lldap -llber -lsasl -lkrb4 -ldes425 -lkrb5 -lk5crypto -lcom_err -lgdbm"
SHAREDLIBS="-lssl -lcrypto -ldb -ldl -lresolv -lc"
LIBS="-L/usr/kerberos/lib -Wl,-Bstatic $STATICLIBS -Wl,-Bdynamic $SHAREDLIBS"
export LIBS

# Build nss_ldap.
%configure --with-ldap=openldap --libdir=/lib
make

# Make a version script so that we can [not export] symbols which glibc doesn't
# need in order to use the module.  This prevents weird crashes when apps
# provide a different version of some of the symbols we use.
cat << EOF > Versions
libnss_ldap {
global:
EOF
nm -g nss_ldap.so | grep _nss_ldap | awk '{print $NF";"}' | sort -u >> Versions;
cat << EOF >> Versions
local:
*;
};
EOF

# Relink using the version script, pulling in the needed libraries statically.
rm nss_ldap.so
make nss_ldap_so_LDFLAGS="-shared -Wl,--version-script=Versions"

# Build pam_ldap.
pushd pam_ldap-%{pam_ldap_version}
touch NEWS
aclocal && automake && autoheader && autoconf
%configure
make
cp -f AUTHORS AUTHORS.pam
cp -f ChangeLog ChangeLog.pam
cp -f README README.pam
popd

%install
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/{etc,lib/security,usr/lib}

# Install the nsswitch module.
make install DESTDIR=$RPM_BUILD_ROOT INST_UID=`id -un` INST_GID=`id -gn`

# Install the module for PAM.
install -m 755 pam_ldap-%{pam_ldap_version}/pam_ldap.so \
	       $RPM_BUILD_ROOT/lib/security/
chmod 755 $RPM_BUILD_ROOT/{lib,/lib/security}/*.so*

# Install the default configuration file, but change the search bases to
# something generic to avoid overloading padl.com servers and to match
# good practice when using DNS domains in example configurations.
sed 's|dc=padl|dc=example|g' ldap.conf > $RPM_BUILD_ROOT/etc/ldap.conf
chmod 644 $RPM_BUILD_ROOT/etc/ldap.conf

# Create a symlink from the nsswitch library to .so file in %{_libdir}
# so that it can be linked directly by apps.
touch $RPM_BUILD_ROOT/rootfile
slashlibdir=lib
while [ ! -f $RPM_BUILD_ROOT/%{_libdir}/${slashlibdir}/../rootfile ] ; do
	slashlibdir=../${slashlibdir}
done
pushd $RPM_BUILD_ROOT/%{_libdir}
ln -s ${slashlibdir}/libnss_ldap-*.so libnss_ldap.so
popd

%clean
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%attr(0755,root,root) /lib/libnss_ldap*.so*
%attr(0755,root,root) /lib/security/*.so*
%attr(0755,root,root) /usr/lib/libnss_ldap*.so
%attr(0644,root,root) %config(noreplace) /etc/ldap.conf
%doc ANNOUNCE AUTHORS ChangeLog COPYING NEWS README
%doc nsswitch.ldap
%doc pam_ldap-%{pam_ldap_version}/{AUTHORS,ChangeLog,README}.pam pam_ldap-%{pam_ldap_version}/pam.d

%changelog
* Thu Jun  6 2002 Nalin Dahyabhai <nalin@redhat.com> 172-3.2
- rebuild

* Tue May 21 2002 Nalin Dahyabhai <nalin@redhat.com> 172-3.1
- build fixes for ia64

* Tue Mar 26 2002 Tim Powers <timp@redhat.com>
- rebuild against new libdb

* Fri Aug 31 2001 Nalin Dahyabhai <nalin@redhat.com>
- link statically with libldap again, because libldap is linked with other
  shared libraries now (keeping us from having files in /usr open when we
  go to shut the system down)

* Thu Aug 30 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 172, fixing schema mapping code
- update to pam_ldap 124, incorporating TLS default option and doc fixes

* Mon Aug  6 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 167, adding support for rebinds

* Tue Jul 24 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 164, fixing the timeout problem correctly
- update to pam_ldap 122, fixing escaping of user name in filters

* Thu Jul 12 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 163, fixing the timeout problem
- update to pam_ldap 120
- add gdbm-devel as a buildprereq, because we list it in $LIBS (#48999)
- add db3-devel as a buildprereq (#48999)
- add pam-devel as a buildprereq (#48999)

* Tue Jul 10 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 161
- attempt to fix hangs when no timeout is specified, or the timeout is 0

* Mon Jul  9 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 160, pam_ldap 119

* Thu Jun 28 2001 Nalin Dahyabhai <nalin@redhat.com>
- patch cleanups

* Tue Jun 26 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 159, pam_ldap 118

* Tue Jun 19 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 153, pam_ldap 117

* Tue May 29 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 152, pam_ldap 111

* Mon May 21 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to pam_ldap 108

* Wed Apr 25 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to pam_ldap 107

* Thu Apr 19 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 150 (incorporates the fail patch)
- update to pam_ldap 106

* Wed Mar  7 2001 Nalin Dahyabhai <nalin@redhat.com>
- make nss_ldap fail when attempting to startup TLS fails, because that's what
  we do when LDAPS doesn't work (and what pam_ldap does already)
- add DNS autoconfiguration to pam_ldap

* Tue Mar  6 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 149, minor fixes for compile glitches
- update to pam_ldap 105, minor fixes (as above) and handles shadow expiration

* Fri Mar  2 2001 Nalin Dahyabhai <nalin@redhat.com>
- rebuild in new environment

* Wed Feb 28 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 146 to get a faster initgroups() back-end

* Mon Feb 12 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 143 to get the official fix for the heap corruption

* Fri Feb  9 2001 Nalin Dahyabhai <nalin@redhat.com>
- fix heap corruption when falling back to DNS SRV records for configuration

* Mon Feb  5 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 142, fixes a memory leak

* Mon Jan 29 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 140, fixes a configure bug and an alignment problem

* Fri Jan 19 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 139

* Mon Jan 15 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 138, which folds in our patch for initgroups
- change the default search base in ldap.conf to dc=example,dc=com

* Wed Jan 10 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 137 and pam_ldap 99
- try to not cause a segfault in _nss_ldap_initgroups

* Wed Jan  3 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 124 and pam_ldap 82

* Thu Dec 28 2000 Nalin Dahyabhai <nalin@redhat.com>
- add a requires: for nscd

* Thu Dec 14 2000 Nalin Dahyabhai <nalin@redhat.com>
- version the NSS module so that it works properly with programs which have
  been linked statically to a different version of an LDAP library, like
  Netscape Communicator

* Wed Dec  6 2000 Nalin Dahyabhai <nalin@redhat.com>
- BuildPrereq gdbm-devel
- pass RPM_OPT_FLAGS as CFLAGS to %%configure
- if protocol version is 2, explicitly set protocol version to 3 before trying
  to start TLS
- add STARTTLS support to nss_ldap
- work around a build-time problem on ia64

* Tue Dec  5 2000 Nalin Dahyabhai <nalin@redhat.com>
- BuildPrereq cyrus-sasl-devel instead of cyrus-sasl

* Mon Nov 20 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 123 and pam_ldap 82

* Fri Oct 27 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 122
- link statically with libsasl, require the first devel package that supplied it

* Thu Oct 19 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 120 and pam_ldap 77

* Wed Oct  4 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 116 and pam_ldap 74

* Fri Sep  7 2000 Nalin Dahyabhai <nalin@redhat.com>
- rebuild in new environment

* Thu Jul 27 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to pam_ldap 67 to fix a bug in template user code
- convert symlink in /usr/lib to a relative one (#16132)

* Thu Jul 27 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 113 and pam_ldap 66

* Wed Jul 12 2000 Prospector <bugzilla@redhat.com>
- automatic rebuild

* Tue Jun 27 2000 Matt Wilson <msw@redhat.com>
- changed all the -,- in attr statements to root,root

* Tue Jun 27 2000 Nalin Dahyabhai <nalin@redhat.com>
- update pam_ldap to 63

* Wed May 31 2000 Nalin Dahyabhai <nalin@redhat.com>
- update pam_ldap to 56

* Tue May 30 2000 Nalin Dahyabhai <nalin@redhat.com>
- update pam_ldap to 55
- back out no-threads patch for pam_ldap, not needed any more

* Thu May 25 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to 110
- revert prototype patch, looks like a problem with the new glibc after all

* Fri May 19 2000 Nalin Dahyabhai <nalin@redhat.com>
- get libpthread out of the NSS module
- fix prototype problems in getpwXXX()

* Mon May 15 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 109

* Sat Apr 29 2000 Nalin Dahyabhai <nalin@redhat.com>
- update pam_ldap 51

* Tue Apr 25 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 108 and pam_ldap 49

* Thu Apr 20 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to pam_ldap 48

* Thu Mar 30 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 107
- note: check http://www.advogato.org/person/lukeh/ for Luke's changelog

* Tue Mar 21 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 106

* Wed Feb  9 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 105

* Mon Feb  7 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 104 and pam_ldap 46
- disable link against libpthread in pam_ldap

* Tue Feb  1 2000 Nalin Dahyabhai <nalin@redhat.com>
- remove migration tools, because this package requires openldap now, which
  also includes them

* Fri Jan 28 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to nss_ldap 103

* Mon Jan 24 2000 Preston Brown <pbrown@redhat.com>
- fix typo in linuxconf-pair pam cfg file (#7800)

* Tue Jan 11 2000 Preston Brown <pbrown@redhat.com>
- v99, made it require pam_ldap
- added perl migration tools
- integrate pam_ldap stuff

* Fri Oct 22 1999 Bill Nottingham <notting@redhat.com>
- statically link ldap libraries (they're in /usr/lib)

* Tue Aug 10 1999 Cristian Gafton <gafton@redhat.com>
- use the ldap.conf file as an external source
- don't forcibly build the support for version 3
- imported the default spec file from the tarball and fixed it up for RH 6.1
